@@ -7,10 +7,10 @@
 #'
 #' **method**
 #'
-#' The original method presented by Baiely et al., 2003 shifted the signal integrals and slightly
+#' The original method presented by Bailey et al., 2003 shifted the signal integrals and slightly
 #' extended them accounting for changes in the counting statistics. Example: `c(1:3, 3:5, 5:7)`.
 #' However, here also another method is provided allowing to expand the signal integral by
-#' consectutively expaning the integral by its chosen length. Example: `c(1:3, 1:5, 1:7)`
+#' consecutively expanding the integral by its chosen length. Example: `c(1:3, 1:5, 1:7)`
 #'
 #' Note that in both cases the integral limits are overlap. The finally applied limits are part
 #' of the function output.
@@ -67,8 +67,9 @@
 #' enables or disables terminal feedback
 #'
 #' @param ... further arguments and graphical parameters passed to
-#' [plot.default], [analyse_SAR.CWOSL] and [analyse_pIRIRSequence].
-#' See details for further information.
+#' [plot.default], [analyse_SAR.CWOSL] and [analyse_pIRIRSequence] (see details for further information).
+#' Plot control parameters are: `ylim`, `xlim`, `ylab`, `xlab`, `main`, `pch`, `mtext`, `cex`, `legend`,
+#' `legend.text`, `legend.pos`
 #'
 #' @return
 #' A plot and an [RLum.Results-class] object with the produced De values
@@ -94,12 +95,11 @@
 #' [analyse_SAR.CWOSL] and [analyse_pIRIRSequence]. However, the integrity
 #' checks of this function are not that thoughtful as in these functions itself.
 #' It means, that every sequence should be checked carefully before running long
-#' calculations using serveral hundreds of channels.
+#' calculations using several hundreds of channels.
 #'
 #' @section Function version: 0.1.3
 #'
-#' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
+#' @author Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @references
 #' Bailey, R.M., Singarayer, J.S., Ward, S., Stokes, S., 2003. Identification of partial resetting
@@ -292,7 +292,8 @@ plot_DetPlot <- function(
       pch = 1,
       mtext = ifelse(is.na(pIRIR_signals[1]), "", paste0("Signal: ",pIRIR_signals[i])),
       cex = 1,
-      legend = c(expression(L[n]-signal), expression(D[e])),
+      legend = TRUE,
+      legend.text = c(expression(L[n]-signal), expression(D[e])),
       legend.pos = "bottomleft"
     )
     plot.settings <- modifyList(plot.settings, list(...))
@@ -342,12 +343,14 @@ plot_DetPlot <- function(
     mtext(side = 3, plot.settings$mtext)
 
     ##legend
-    legend(
-      plot.settings$legend.pos,
-      legend = plot.settings$legend,
-      pch = c(plot.settings$pch, 20),
-      bty = "n"
-    )
+    if(plot.settings$legend){
+      legend(
+        plot.settings$legend.pos,
+        legend = plot.settings$legend.text,
+        pch = c(plot.settings$pch, 20),
+        bty = "n"
+      )
+    }
 
     ##set return
     return(df_final)
