@@ -1,8 +1,11 @@
-#' Fit and plot a growth curve for luminescence data (Lx/Tx against dose)
+#' @title Fit and plot a growth curve for luminescence data (Lx/Tx against dose)
 #'
+#' @description
 #' A dose response curve is produced for luminescence measurements using a
 #' regenerative or additive protocol. The function supports interpolation and
-#' extraxpolation to calculate the equivalent dose.
+#' extrapolation to calculate the equivalent dose.
+#'
+#' @details
 #'
 #' **Fitting methods**
 #'
@@ -47,6 +50,16 @@
 #' where **c > 0** is a kinetic order modifier
 #' (not to be confused with **c** in `EXP` or `EXP+LIN`!).
 #'
+#' `LambertW`: tries to fit a dose-response curve based on the Lambert W function
+#' according to Pagonis et al. (2020). The function has the form
+#'
+#' \deqn{y ~ (1 + (W((R - 1) * exp(R - 1 - ((x + D_{int}) / D_{c}))) / (1 - R))) * N}
+#'
+#' with \eqn{W} the Lambert W function, calculated using the package [lamW::lambertW0],
+#' \eqn{R} the dimensionless detrapping ratio, \eqn{N} the total concentration
+#' of trappings states in cm^-3 and \eqn{D_{c} = N/R} a constant. \eqn{D_{int}} is
+#' the offset on the x-axis.
+#'
 #' **Fit weighting**
 #'
 #' If the option `fit.weights =  TRUE` is chosen, weights are calculated using
@@ -55,25 +68,30 @@
 #'
 #' **Error estimation using Monte Carlo simulation**
 #'
-#' Error estimation is done using a Monte Carlo (MC) simulation approach. A set of Lx/Tx values is
-#' constructed by randomly drawing curve data from samled from normal
-#' distributions. The normal distribution is defined by the input values (mean
-#' = value, sd = value.error). Then, a growth curve fit is attempted for each
-#' dataset resulting in a new distribution of single De values. The [sd]
-#' of this distribution is becomes then the error of the De. With increasing
-#' iterations, the error value becomes more stable.
+#' Error estimation is done using a parametric bootstrapping approach. A set of
+#' `Lx/Tx` values is constructed by randomly drawing curve data sampled from normal
+#' distributions. The normal distribution is defined by the input values (`mean
+#' = value`, `sd = value.error`). Then, a dose-response curve fit is attempted for each
+#' dataset resulting in a new distribution of single `De` values. The standard
+#' deviation of this distribution is becomes then the error of the `De`. With increasing
+#' iterations, the error value becomes more stable. However, naturally the error
+#' will not decrease with more MC runs.
+#'
+#' Alternatively, the function returns highest probability density interval
+#' estimates as output, users may find more useful under certain circumstances.
+#'
 #' **Note:** It may take some calculation time with increasing MC runs,
 #' especially for the composed functions (`EXP+LIN` and `EXP+EXP`).\cr
 #' Each error estimation is done with the function of the chosen fitting method.
 #'
 #' **Subtitle information**
 #'
-#' To avoid plotting the subtitle information, provide an empty user mtext
+#' To avoid plotting the subtitle information, provide an empty user `mtext`
 #' `mtext = ""`. To plot any other subtitle text, use `mtext`.
 #'
 #' @param sample [data.frame] (**required**):
-#' data frame with three columns for x=Dose,y=LxTx,z=LxTx.Error, y1=TnTx.
-#' The column for the test dose response is optional, but requires 'TnTx' as
+#' data frame with three columns for `x=Dose`,`y=LxTx`,`z=LxTx.Error`, `y1=TnTx`.
+#' The column for the test dose response is optional, but requires `'TnTx'` as
 #' column name if used. For exponential fits at least three dose points
 #' (including the natural) should be provided.
 #'
@@ -86,7 +104,7 @@
 #' - `"extrapolation"` calculates the De by extrapolation and
 #' - `"alternate"` calculates no De and just fits the data points.
 #'
-#' Please note that for option `"regenrative"` the first point is considered
+#' Please note that for option `"regenerative"` the first point is considered
 #' as natural dose
 #'
 #' @param fit.method [character] (*with default*):
@@ -96,15 +114,16 @@
 #' - `EXP`,
 #' - `EXP OR LIN`,
 #' - `EXP+LIN`,
-#' - `EXP+EXP` or
-#' - `GOK`.
+#' - `EXP+EXP`,
+#' - `GOK`,
+#' - `LambertW`
 #'
 #' See details.
 #'
 #' @param fit.force_through_origin [logical] (*with default*)
 #' allow to force the fitted function through the origin.
-#' For `method = "EXP+EXP"` and `method = "GOK"` the function will go through the origin in either case,
-#' so this option will have no effect.
+#' For `method = "EXP+EXP"` and `method = "GOK"` the function will go through
+#' the origin in either case, so this option will have no effect.
 #'
 #' @param fit.weights [logical] (*with default*):
 #' option whether the fitting is done with or without weights. See details.
@@ -123,7 +142,7 @@
 #'
 #' @param fit.bounds [logical] (*with default*):
 #' set lower fit bounds for all fitting parameters to 0. Limited for the use
-#' with the fit methods `EXP`, `EXP+LIN`, `EXP OR LIN` and `GOK`.
+#' with the fit methods `EXP`, `EXP+LIN`, `EXP OR LIN`, `GOK`, `LambertW`
 #' Argument to be inserted for experimental application only!
 #'
 #' @param NumberIterations.MC [integer] (*with default*):
@@ -150,8 +169,8 @@
 #' global scaling factor.
 #'
 #' @param txtProgressBar [logical] (*with default*):
-#' enables or disables txtProgressBar. If `verbose = FALSE` also no
-#' txtProgressBar is shown.
+#' enables or disables `txtProgressBar`. If `verbose = FALSE` also no
+#' `txtProgressBar` is shown.
 #'
 #' @param verbose [logical] (*with default*):
 #' enables or disables terminal feedback.
@@ -174,10 +193,10 @@
 #' `..$call` : \tab `call` \tab The original function call\cr
 #' }
 #'
-#' @section Function version: 1.10.11
+#' @section Function version: 1.11.2
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)\cr
+#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)\cr
 #' Michael Dietze, GFZ Potsdam (Germany)
 #'
 #' @references
@@ -188,8 +207,11 @@
 #' Herman, F., 2015. Radiation-induced growth and isothermal decay of infrared-stimulated luminescence
 #' from feldspar. Radiation Measurements 81, 224-231.
 #'
+#' Pagonis, V., Kitis, G., Chen, R., 2020. A new analytical equation for the dose response of dosimetric materials,
+#' based on the Lambert W function. Journal of Luminescence 225, 117333. \doi{10.1016/j.jlumin.2020.117333}
+#'
 #' @seealso [nls], [RLum.Results-class], [get_RLum], [minpack.lm::nlsLM],
-#' [lm], [uniroot]
+#' [lm], [uniroot], [lamW::lambertW0]
 #'
 #' @examples
 #'
@@ -310,6 +332,16 @@ plot_GrowthCurve <- function(
     )
   )
 
+  ##2. Check supported fit methods
+  fit.method_supported <- c("LIN", "QDR", "EXP", "EXP OR LIN", "EXP+LIN", "EXP+EXP", "GOK", "LambertW")
+  if (!fit.method[1] %in% fit.method_supported) {
+    stop(paste0(
+      "[plot_GrowthCurve()] fit method not supported, supported methods are: ",
+      paste(fit.method_supported, collapse = ", ")
+    ),
+    call. = FALSE)
+  }
+
   ##2. check if sample contains a least three rows
   if(length(sample[[1]])<3 & fit.method != "LIN"){
     stop("\n [plot_GrowthCurve()] At least two regeneration points are needed!", call. = FALSE)
@@ -322,10 +354,8 @@ plot_GrowthCurve <- function(
 
   }
 
-
   ##2.2 check for inf data in the data.frame
   if(any(is.infinite(unlist(sample)))){
-
       #https://stackoverflow.com/questions/12188509/cleaning-inf-values-from-an-r-dataframe
       #This is slow, but it does not break with previous code
       sample <- do.call(data.frame, lapply(sample, function(x) replace(x, is.infinite(x),NA)))
@@ -417,7 +447,12 @@ plot_GrowthCurve <- function(
     }
 
   }else{
-    fit.weights <- rep(1, length(abs(y.Error)))
+    if(sum(y.Error) == 0) {
+      fit.weights <- NA
+
+    } else {
+      fit.weights <- rep(1, length(abs(y.Error)))
+    }
 
   }
 
@@ -467,8 +502,7 @@ plot_GrowthCurve <- function(
   x.natural <- NA
 
   ##1.4 set initialise variables
-  De <- NA
-  De.Error <- NA
+  De <- De.Error <- D01 <-  R <-  Dc <- N <- NA
 
 
   ##============================================================================##
@@ -494,6 +528,11 @@ plot_GrowthCurve <- function(
   fit.functionGOK <- function(a,b,c,x) { a*(1-(1+(1/b)*x*c)^(-1/c)) }
   fit.formulaGOK <- y ~ a*(1-(1+(1/b)*x*c)^(-1/c))
 
+  #Lambert W
+  fit.functionLambertW <- function(R, Dc, N, Dint, x) {
+    (1 + (lamW::lambertW0((R - 1) * exp(R - 1 - ((x + Dint) / Dc ))) / (1 - R))) * N }
+  fit.formulaLambertW <- y ~ (1 + (lamW::lambertW0((R - 1) * exp(R - 1 - ((x + Dint) / Dc ))) / (1 - R))) * N
+
   ##input data for fitting; exclude repeated RegPoints
   if (fit.includingRepeatedRegPoints == FALSE) {
     data <-
@@ -531,7 +570,7 @@ plot_GrowthCurve <- function(
   ##--------------------------------------------------------------------------##
   ##general setting of start parameters for fitting
 
-  ##a - estimation for a a the maxium of the y-values (Lx/Tx)
+  ##a - estimation for a a the maximum of the y-values (Lx/Tx)
   a <- max(data[,2])
 
   ##b - get start parameters from a linear fit of the log(y) data
@@ -592,7 +631,6 @@ plot_GrowthCurve <- function(
 
     ##Do fitting with option to force curve through the origin
     if(fit.force_through_origin){
-
       ##linear fitting ... polynomial
       fit  <- lm(data$y ~  0 + I(data$x) + I(data$x^2), weights = fit.weights)
 
@@ -681,7 +719,6 @@ plot_GrowthCurve <- function(
       data <- data.frame(x=xy$x, y=data.MC[,i])
 
       if(fit.force_through_origin){
-
         ##linear fitting ... polynomial
         fit.MC  <- lm(data$y ~  0 + I(data$x) + I(data$x^2), weights = fit.weights)
 
@@ -764,7 +801,6 @@ plot_GrowthCurve <- function(
   #EXP ---------------
 
   if (fit.method=="EXP" | fit.method=="EXP OR LIN" | fit.method=="LIN"){
-
     if((is.na(a) | is.na(b) | is.na(c)) && fit.method != "LIN"){
       try(stop("[plot_GrowthCurve()] Fit could not be applied for this data set. NULL returned!", call. = FALSE))
       return(NULL)
@@ -872,7 +908,6 @@ plot_GrowthCurve <- function(
 
         }
 
-
         #print D01 value
         D01 <- b
         if (verbose) {
@@ -973,7 +1008,7 @@ plot_GrowthCurve <- function(
     ##LIN -----
     ##two options: just linear fit or LIN fit after the EXP fit failed
 
-    #set fit object, if fit objekt was not set before
+    #set fit object, if fit object was not set before
     if(exists("fit")==FALSE){fit<-NA}
 
     if ((fit.method=="EXP OR LIN" & class(fit)=="try-error") |
@@ -1605,7 +1640,6 @@ plot_GrowthCurve <- function(
   }
   else if (fit.method=="GOK") {
   #==========================================================================
-  #==========================================================================
   # GOK -----
 
     # FINAL Fit
@@ -1677,9 +1711,9 @@ plot_GrowthCurve <- function(
       #	--take De_Error
 
       #set variables
-      var.b<-vector(mode="numeric", length=NumberIterations.MC)
-      var.a<-vector(mode="numeric", length=NumberIterations.MC)
-      var.c<-vector(mode="numeric", length=NumberIterations.MC)
+      var.b <- vector(mode = "numeric", length = NumberIterations.MC)
+      var.a <- vector(mode = "numeric", length = NumberIterations.MC)
+      var.c <- vector(mode = "numeric", length = NumberIterations.MC)
 
       #start loop
       for (i in 1:NumberIterations.MC) {
@@ -1687,7 +1721,8 @@ plot_GrowthCurve <- function(
         ##set data set
         data <- data.frame(x = xy$x,y = data.MC[,i])
 
-        fit.MC <- try(minpack.lm::nlsLM(
+        fit.MC <- try(
+        {minpack.lm::nlsLM(
           formula = fit.formulaGOK,
           data = data,
           start = list(a = a, b = b, c = 1),
@@ -1701,8 +1736,7 @@ plot_GrowthCurve <- function(
           },
           upper = c(Inf, Inf, Inf),
           control = minpack.lm::nls.lm.control(maxiter = 500)
-        ), silent = TRUE
-        )
+        )}, silent = TRUE)
 
         # get parameters out of it including error handling
         if (class(fit.MC)=="try-error") {
@@ -1712,9 +1746,9 @@ plot_GrowthCurve <- function(
 
           # get parameters out
           parameters<-coef(fit.MC)
-          var.b[i]<-as.vector((parameters["b"])) #D0
-          var.a[i]<-as.vector((parameters["a"])) #Imax
-          var.c[i]<-as.vector((parameters["c"])) #kinetic order modifier
+          var.b[i] <- as.vector((parameters["b"])) #D0
+          var.a[i] <- as.vector((parameters["a"])) #Imax
+          var.c[i] <- as.vector((parameters["c"])) #kinetic order modifier
 
           # calculate x.natural for error calculation
           if(mode == "interpolation"){
@@ -1741,14 +1775,196 @@ plot_GrowthCurve <- function(
 
       ##remove values
       rm(var.b, var.a, var.c)
+      }
+    } else if (fit.method=="LambertW") {
+    #==========================================================================
+    # LambertW -----
+    if(mode == "extrapolation"){
+      Dint_lower <- 50 ##TODO - fragile ... however it is only used by a few
+
+    } else{
+      Dint_lower <- 0.01
+
+    }
+
+    fit <- try(minpack.lm::nlsLM(
+          formula = fit.formulaLambertW,
+          data = data,
+          start = list(R = 0, Dc = b, N = b, Dint = 0),
+          weights = fit.weights,
+          trace = FALSE,
+          algorithm = "LM",
+          lower = if (fit.bounds) c(0, 0, 0, Dint_lower) else c(-Inf,-Inf,-Inf, -Inf),
+          upper = if(fit.force_through_origin) c(10, Inf, Inf, 0) else c(10, Inf, Inf, Inf),
+          control = minpack.lm::nls.lm.control(maxiter = 500)
+        ), silent = TRUE)
+
+        if (inherits(fit, "try-error")){
+          if(verbose) writeLines("[plot_GrowthCurve()] try-error for LambertW fit")
+
+        }else{
+          #get parameters out of it
+          parameters <- coef(fit)
+          R <- as.vector((parameters["R"]))
+          Dc <- as.vector((parameters["Dc"]))
+          N <- as.vector((parameters["N"]))
+          Dint <- as.vector((parameters["Dint"]))
+
+          #calculate De
+          if(mode == "interpolation"){
+             De <- try(suppressWarnings(stats::uniroot(
+               f = function(x, R, Dc, N, Dint, LnTn) {
+                 fit.functionLambertW(R, Dc, N, Dint, x) - LnTn},
+               interval = c(0, max(sample[[1]]) * 1.2),
+               R = R,
+               Dc = Dc,
+               N = N,
+               Dint = Dint,
+               LnTn = sample[1,2])$root), silent = TRUE)
+
+          }else if (mode == "extrapolation"){
+            De <- try(suppressWarnings(stats::uniroot(
+              f = function(x, R, Dc, N, Dint) {
+                fit.functionLambertW(R, Dc, N, Dint, x)},
+              interval = c(-max(sample[[1]]),0),
+              R = R,
+              Dc = Dc,
+              N = N,
+              Dint = Dint)$root), silent = TRUE)
+
+            ## there are cases where the function cannot calculate the root
+            ## due to its shape, here we have to use the minimum
+            if(inherits(De, "try-error")){
+              De <- try(suppressWarnings(stats::optimize(
+                f = function(x, R, Dc, N, Dint) {
+                  fit.functionLambertW(R, Dc, N, Dint, x)},
+                interval = c(-max(sample[[1]]),0),
+                R = R,
+                Dc = Dc,
+                N = N,
+                Dint = Dint)$minimum), silent = TRUE)
+            }
+
+          }
+
+          if(inherits(De, "try-error")) De <- NA
+
+          if (verbose) {
+            if (mode != "alternate") {
+              writeLines(paste0(
+                "[plot_GrowthCurve()] Fit: ",
+                fit.method,
+                " (",
+                mode,
+                ")",
+                " | De = ",
+                round(abs(De), digits = 2),
+                " | R = ",
+                round(R,2),
+                " | Dc = ",
+                round(Dc, digits = 2)
+              ))
+            }
+          }
+
+          #LambertW MC -----
+          ##Monte Carlo Simulation
+          #	--Fit many curves and calculate a new De +/- De_Error
+          #	--take De_Error
+
+          #set variables
+          var.R <-  var.Dc <- var.N <- var.Dint <- vector(
+            mode = "numeric", length = NumberIterations.MC)
+
+          #start loop
+          for (i in 1:NumberIterations.MC) {
+            ##set data set
+            data <- data.frame(x = xy$x,y = data.MC[,i])
+            fit.MC <- try(minpack.lm::nlsLM(
+              formula = fit.formulaLambertW,
+              data = data,
+              start = list(R = 0, Dc = b, N = 0, Dint = 0),
+              weights = fit.weights,
+              trace = FALSE,
+              algorithm = "LM",
+              lower = if (fit.bounds) c(0, 0, 0, Dint*runif(1,0,2)) else c(-Inf,-Inf,-Inf, -Inf),
+              upper = if(fit.force_through_origin) c(10, Inf, Inf, 0) else c(10, Inf, Inf, Inf),
+              control = minpack.lm::nls.lm.control(maxiter = 500)
+            ), silent = TRUE)
+
+            # get parameters out of it including error handling
+            x.natural[i] <- NA
+            if (!inherits(fit.MC, "try-error")) {
+              # get parameters out
+              parameters<-coef(fit.MC)
+              var.R[i] <- as.vector((parameters["R"]))
+              var.Dc[i] <- as.vector((parameters["Dc"]))
+              var.N[i] <- as.vector((parameters["N"]))
+              var.Dint[i] <- as.vector((parameters["Dint"]))
+
+              # calculate x.natural for error calculation
+              if(mode == "interpolation"){
+                x.natural[i]<-try(
+                {suppressWarnings(stats::uniroot(
+                  f = function(x, R, Dc, N, Dint, LnTn) {
+                    fit.functionLambertW(R, Dc, N, Dint, x) - LnTn},
+                  interval = c(0, max(sample[[1]]) * 1.2),
+                  R = var.R[i],
+                  Dc = var.Dc[i],
+                  N = var.N[i],
+                  Dint = var.Dint[i],
+                  LnTn = data.MC.De[i])$root)
+                }, silent = TRUE)
+
+              }else if(mode == "extrapolation"){
+                try <- try(
+                  suppressWarnings(stats::uniroot(
+                    f = function(x, R, Dc, N, Dint) {
+                      fit.functionLambertW(R, Dc, N, Dint, x)},
+                    interval = c(-max(sample[[1]]), 0),
+                    R = var.R[i],
+                    Dc = var.Dc[i],
+                    N = var.N[i],
+                    Dint = var.Dint[i])$root),
+                  silent = TRUE)
+
+                if(inherits(try, "try-error")){
+                  try <- try(suppressWarnings(stats::optimize(
+                    f = function(x, R, Dc, N, Dint) {
+                      fit.functionLambertW(R, Dc, N, Dint, x)},
+                    interval = c(-max(sample[[1]]),0),
+                    R = var.R[i],
+                    Dc = var.Dc[i],
+                    N = var.N[i],
+                    Dint = var.Dint[i])$minimum),
+                    silent = TRUE)
+
+                }
+
+                if(!inherits(try, "try-error"))
+                  x.natural[i] <- try
+
+              }
+
+            }
+
+          }#end for loop
+
+          ##we need absolute numbers
+          x.natural <- abs(x.natural)
+
+          ##write Dc.ERROR
+          Dc.ERROR <- sd(var.Dc, na.rm = TRUE)
+
+          ##remove values
+          rm(var.R, var.Dc, var.N, var.Dint)
 
     }#endif::try-error fit
 
-
   #===========================================================================
   }#End if Fit Method
 
-  #Get De values from Monto Carlo simulation
+  #Get De values from Monte Carlo simulation
 
   #calculate mean and sd (ignore NaN values)
   De.MonteCarlo <- mean(na.exclude(x.natural))
@@ -1756,16 +1972,8 @@ plot_GrowthCurve <- function(
   #De.Error is Error of the whole De (ignore NaN values)
   De.Error <- sd(na.exclude(x.natural))
 
-  ##choose format in dependency of the size of the error
-  De.Error <- ifelse(De.Error <= 0.01,
-                     format(De.Error, scientific = TRUE, digits = 2),
-                     round(De.Error, digits = 2))
-
-
-
   # Formula creation --------------------------------------------------------
   if(!is(fit,"try-error") & !is.na(fit[1])){
-
     if(fit.method == "EXP") {
       f <- parse(text = paste0(format(coef(fit)[1], scientific = TRUE), " * (1 - exp( - ( x + ",
                                format(coef(fit)[3], scientific = TRUE), ") / ",
@@ -1822,8 +2030,18 @@ plot_GrowthCurve <- function(
         ))
     }
 
-  }else{
+    if(fit.method == "LambertW") {
+      f <- paste0(
+        "(1 + W[",format(coef(fit)[1], scientific = TRUE)," - 1 * exp(",
+        format(coef(fit)[1], scientific = TRUE), " - 1 - ((x + ",
+        format(coef(fit)[4], scientific = TRUE), ") / ",
+        format(coef(fit)[2], scientific = TRUE), "))] / (1 - ",
+        format(coef(fit)[2], scientific = TRUE), ")) * ",
+        format(coef(fit)[3], scientific = TRUE)
+      )
+    }
 
+  }else{
     f <- NA
 
   }
@@ -1834,7 +2052,6 @@ plot_GrowthCurve <- function(
   ##5. Plotting if plotOutput==TRUE
   if(output.plot) {
 
-
     # Deal with extra arguments -----------------------------------------------
     ##deal with addition arguments
     extraArgs <- list(...)
@@ -1934,7 +2151,6 @@ plot_GrowthCurve <- function(
       temp.xy.plot  <- sample[fit.RegPointsReal,]
 
     }else{
-
       temp.xy.plot  <- xy[1:fit.NumberRegPointsReal,]
 
     }
@@ -1996,6 +2212,9 @@ plot_GrowthCurve <- function(
       else if (fit.method == "GOK") {
         try(curve(fit.functionGOK(a, b, c, x), lwd = 1.5, add = TRUE))
       }
+      else if (fit.method == "LambertW") {
+        try(curve(fit.functionLambertW(R, Dc, N, Dint, x), lwd = 1.5, add = TRUE, n = 10000))
+      }
 
       ##POINTS	#Plot Reg0 and Repeated Points
 
@@ -2067,7 +2286,7 @@ plot_GrowthCurve <- function(
         if(mode != "alternate"){
         substitute(D[e] == De,
                    list(De = paste(
-                     round(abs(De), digits = 2), "\u00B1", round(as.numeric(De.Error), digits = 2), " | fit: ", fit.method
+                     round(abs(De), digits = 2), "\u00B1", format(De.Error, scientific = TRUE, digits = 2), " | fit: ", fit.method
                    )))
         }else{
           ""
@@ -2148,13 +2367,7 @@ plot_GrowthCurve <- function(
             border = "white",
             axes = FALSE,
             ylim = c(0, max(norm.curve.y)),
-            sub =
-              paste(
-                "n = ",
-                NumberIterations.MC,
-                ", valid fits =",
-                length(na.exclude(x.natural))
-              ),
+            sub = paste0("valid fits = ", length(na.exclude(x.natural)), "/",NumberIterations.MC),
             col = "grey"
           ), silent = TRUE)
 
@@ -2183,13 +2396,11 @@ plot_GrowthCurve <- function(
                       substitute(D[e[MC]] == De,
                                  list(
                                    De = paste(
-                                     round(De.MonteCarlo, 2),
+                                     abs(round(De.MonteCarlo, 2)),
                                      "\u00B1",
-                                     round(De.Error,2),
-                                     " | quality = ",
-                                     round((1 - abs(De - De.MonteCarlo) / De) * 100,
-                                           digits =
-                                             1),
+                                     format(De.Error, scientific = TRUE, digits = 2),
+                                     " | diff. = ",
+                                     abs(round((abs(abs(De) - De.MonteCarlo) / abs(De)) * 100,1)),
                                      "%"
                                    )
                                  )),
@@ -2205,7 +2416,7 @@ plot_GrowthCurve <- function(
             NA,
             xlim = c(0, 10),
             ylim = c(0, 10),
-            main = expression(paste(D[e], " from Monte Carlo simulation"))),
+            main = expression(paste(D[e], " from MC runs"))),
             silent = TRUE
           )
 
@@ -2218,7 +2429,7 @@ plot_GrowthCurve <- function(
 
 
         ##PLOT		#PLOT test dose response curve if available if not plot not available
-        #plot Tx/Tn value for sensitiviy change
+        #plot Tx/Tn value for sensitvity change
         if (!is(plot_check, "try-error")) {
           if ("TnTx" %in% colnames(sample) == TRUE) {
             plot(
@@ -2263,7 +2474,17 @@ plot_GrowthCurve <- function(
 
   }
 
-  ##RETURN - return De values and parameter
+
+# Output ------------------------------------------------------------------
+  ##calculate HPDI
+  HPDI <- matrix(c(NA,NA,NA,NA), ncol = 4)
+  if(!any(is.na(x.natural))){
+    HPDI <- cbind(
+      .calc_HPDI(x.natural, prob = 0.68)[1, ,drop = FALSE],
+      .calc_HPDI(x.natural, prob = 0.95)[1, ,drop = FALSE])
+
+  }
+
   output <- try(data.frame(
     De = abs(De),
     De.Error = De.Error,
@@ -2271,8 +2492,13 @@ plot_GrowthCurve <- function(
     D01.ERROR = D01.ERROR,
     D02 = D02,
     D02.ERROR = D02.ERROR,
+    Dc = Dc,
     De.MC = De.MonteCarlo,
-    Fit = fit.method
+    Fit = fit.method,
+    HPDI68_L = HPDI[1,1],
+    HPDI68_U = HPDI[1,2],
+    HPDI95_L = HPDI[1,3],
+    HPDI95_U = HPDI[1,4]
   ),
   silent = TRUE
   )
@@ -2293,4 +2519,3 @@ plot_GrowthCurve <- function(
   invisible(output.final)
 
 }
-
