@@ -1,18 +1,19 @@
-context("calc_FastRatio")
-
 data("ExampleData.CW_OSL_Curve")
 temp <- calc_FastRatio(ExampleData.CW_OSL_Curve, plot = FALSE, verbose = FALSE)
 
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 5)
 
 })
 
 test_that("check values from output", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   results <- get_RLum(temp)
 
